"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getStoreType = (store) => {
    return {
        actionContext: {},
        rootState: {},
        rootGetters: {},
        storeInstance: {},
    };
};
exports.getAccessorType = (store) => {
    return {};
};
const createAccessor = (store, { getters, state, mutations, actions }, namespace = '') => {
    const namespacedPath = namespace ? `${namespace}/` : '';
    const accessor = {};
    Object.keys(getters || {}).forEach(getter => {
        Object.defineProperty(accessor, getter, {
            get: () => store.getters[`${namespacedPath}${getter}`],
        });
    });
    Object.keys(state ? (typeof state === 'function' ? state() : state) : {}).forEach(prop => {
        if (!Object.getOwnPropertyNames(accessor).includes(prop)) {
            if (namespace) {
                Object.defineProperty(accessor, prop, {
                    get: () => store.state[namespace][prop],
                });
            }
            else {
                Object.defineProperty(accessor, prop, {
                    get: () => store.state[prop],
                });
            }
        }
    });
    Object.keys(mutations || {}).forEach(mutation => {
        accessor[mutation] = (mutationPayload) => store.commit(`${namespacedPath}${mutation}`, mutationPayload);
    });
    Object.keys(actions || {}).forEach(action => {
        accessor[action] = (actionPayload) => store.dispatch(`${namespacedPath}${action}`, actionPayload);
    });
    return accessor;
};
exports.useAccessor = (store, input) => {
    const accessor = createAccessor(store, input);
    Object.keys(input.modules || {}).forEach(namespace => {
        accessor[namespace] = createAccessor(store, input.modules[namespace], namespace);
    });
    const storeType = exports.getAccessorType(input);
    return accessor;
};
exports.getAccessorFromStore = (pattern) => {
    return (store) => exports.useAccessor(store, pattern._modules.root._rawModule);
};
exports.getterTree = (_state, tree) => tree;
exports.mutationTree = (_state, tree) => tree;
exports.actionTree = (_store, tree) => tree;
//# sourceMappingURL=utils.js.map